NetworkFitter — FracAbility 0.1.0 documentation

Skip to main content
`Ctrl`+`K`

# NetworkFitter

class fracability.operations.Statistics.NetworkFitter(obj=None)

  Class used to fit a Fracture or Fracture network object

  best_fit() → Series

    Return the best fit in the fit records dataframe :return:

  find_best_distribution(distribution_list: list | None = None) → Series

    Method used to find the best distribution using BIC ranking :param distribution_list: list of distribution to test :return:

  fit(distribution_name: str)

    Fit the data of the entity_df using scipy available distributions :param distribution_name: Name of the distribution to fit :return:

  property fit_records: DataFrame

    Return the sorted fit dataframe

  get_fitted_distribution(distribution_name: str) → NetworkDistribution

    get the fitted NetworkDistribution object :param distribution_name: name of the distribution :return:

  get_fitted_distribution_list(distribution_names: list | None = None) → list

    Get a list of NetworkDistribution objects fot the given distribution name :param distribution_names: :return:

  get_fitted_parameters(distribution_name: str) → tuple

    Get the fitted distributions parameters in the fit records df :param distribution_name: Name of the distribution

  get_fitted_parameters_list(distribution_names: list | None = None) → list

    Get the parameters of the computed fit(s) :return: Pandas DataFrame

  property net_data: NetworkData

    Property that returns or sets a NetworkData object :return:

  rejected_fit() → DataFrame

    Return the fit records dataframe without the best fit :return: